@@ -1,7 +1,7 @@
 /* -*- Mode: C++; indent-tabs-mode: nil; tab-width: 4 -*-
  * -*- coding: utf-8 -*-
  *
- * Copyright (C) 2020 KylinSoft Co., Ltd.
+ * Copyright (C) 2023 KylinSoft Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
 
 #include <QDebug>
 #include <QString>
-#include <clib-syslog.h>
+#include "clib-syslog.h"
 
 struct QGSettingsPrivate
 {
@@ -53,6 +53,15 @@ void QGSettingsPrivate::settingChanged(GSettings *, const gchar *key, gpointer u
     QMetaObject::invokeMethod(self, "changed", Qt::AutoConnection, Q_ARG(QString, key));
 }
 
+static bool is_item_in_schema (const gchar* const* items, const QByteArray & item)
+{
+    while (*items) {
+       if (g_strcmp0 (*items++, item) == 0) {
+           return true;
+       }
+    }
+    return false;
+}
 
 QGSettings::QGSettings(const QByteArray &schemaId, const QByteArray &path, QObject *parent) : QObject(parent)
 {
@@ -60,6 +69,11 @@ QGSettings::QGSettings(const QByteArray &schemaId, const QByteArray &path, QObje
     mPriv->schemaId = schemaId;
     mPriv->path = path;
 
+    if (false == is_item_in_schema (g_settings_list_schemas(), schemaId)){
+        mPriv->settings = nullptr;
+        return;
+    }
+
     if (mPriv->path.isEmpty()) {
         mPriv->settings = g_settings_new(mPriv->schemaId.constData());
     } else {
@@ -83,9 +97,18 @@ QGSettings::~QGSettings()
 QVariant QGSettings::get(const QString &key) const
 {
     gchar *gkey = unqtify_name(key);
+    if (mPriv->settings == nullptr) {
+        return -1;
+    }
+
+    if (!keys().contains(gkey)) {
+        USD_LOG(LOG_ERR, "can't find int key:%s in %s", gkey, mPriv->schemaId.data());
+        return QVariant(0);
+    }
+
     GVariant *value = g_settings_get_value(mPriv->settings, gkey);
     if( NULL == value) {
-        USD_LOG(LOG_DEBUG,"g_settings_get_value is faild");
+        USD_LOG(LOG_DEBUG,"g_settings_get_value is failed");
         return QVariant(0);
     }
     QVariant qvalue = qconf_types_to_qvariant(value);
@@ -97,8 +120,16 @@ QVariant QGSettings::get(const QString &key) const
 
 void QGSettings::set(const QString &key, const QVariant &value)
 {
-    if (!trySet(key, value))
-        qWarning("unable to set key '%s' to value '%s'", key.toUtf8().constData(), value.toString().toUtf8().constData());
+    if (mPriv->settings == nullptr) {
+        return;
+    }
+    gchar *gkey = unqtify_name(key);
+    if (keys().contains(gkey)) {
+        if (!trySet(key, value))
+            USD_LOG(LOG_ERR,"unable to set key '%s' to value '%s'", key.toUtf8().constData(), value.toString().toUtf8().constData());
+    } else {
+         USD_LOG(LOG_ERR, "can't find int key:%s in %s", gkey, mPriv->schemaId.data());
+    }
 }
 
 bool QGSettings::trySet(const QString &key, const QVariant &value)
@@ -106,9 +137,9 @@ bool QGSettings::trySet(const QString &key, const QVariant &value)
     gchar *gkey = unqtify_name(key);
     bool success = false;
 
+
     /* fetch current value to find out the exact type */
     GVariant *cur = g_settings_get_value(mPriv->settings, gkey);
-
     GVariant *new_value = qconf_types_collect_from_variant(g_variant_get_type (cur), value);
     if (new_value)
         success = g_settings_set_value(mPriv->settings, gkey, new_value);
@@ -121,12 +152,18 @@ bool QGSettings::trySet(const QString &key, const QVariant &value)
 
 void QGSettings::setEnum(const QString& key,int value)
 {
+    if (mPriv->settings == nullptr) {
+        return ;
+    }
     g_settings_set_enum (mPriv->settings,key.toLatin1().data(),value);
 }
 
 int QGSettings::getEnum(const QString& key)
 {
     int enumNum;
+    if (mPriv->settings == nullptr) {
+        return -1;
+    }
     enumNum = g_settings_get_enum (mPriv->settings,key.toLatin1().data());
     return enumNum;
 }
