@@ -1,7 +1,7 @@
 /* -*- Mode: C++; indent-tabs-mode: nil; tab-width: 4 -*-
  * -*- coding: utf-8 -*-
  *
- * Copyright (C) 2020 KylinSoft Co., Ltd.
+ * Copyright (C) 2023 KylinSoft Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@ class PluginInterface;
 class PluginInterface
 {
 public:
-    virtual ~PluginInterface() {};
+    virtual ~PluginInterface() {}
 
     virtual void activate () = 0;
     virtual void deactivate () = 0;
