@@ -1,7 +1,7 @@
 /* -*- Mode: C++; indent-tabs-mode: nil; tab-width: 4 -*-
  * -*- coding: utf-8 -*-
  *
- * Copyright (C) 2020 KylinSoft Co., Ltd.
+ * Copyright (C) 2023 KylinSoft Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,7 +35,7 @@
 
 XEventMonitor *XEventMonitor::instance_ = new XEventMonitor();
 
-QVector<KeySym> ModifiersVec{
+const static QVector<KeySym> ModifiersVec{
     XK_Control_L,
     XK_Control_R,
     XK_Shift_L,
@@ -136,7 +136,7 @@ void XEventMonitorPrivate::run()
 
     // Receive KeyPress, KeyRelease, ButtonPress, ButtonRelease and MotionNotify events.
     memset(range, 0, sizeof(XRecordRange));
-    range->device_events.first = KeyPress;
+    range->device_events.first = XI_KeyPress;
     range->device_events.last  = MotionNotify;
 
     // And create the XRECORD context.
@@ -176,26 +176,29 @@ void XEventMonitorPrivate::handleRecordEvent(XRecordInterceptData* data)
         xEvent * event = (xEvent *)data->data;
         switch (event->u.u.type)
         {
-        case ButtonPress:
-            if (filterWheelEvent(event->u.u.detail)) {
-                emitButtonSignal("buttonPress", event);
-            }
-            break;
-        case MotionNotify:
-            emitButtonSignal("buttonDrag", event);
-            break;
-        case ButtonRelease:
-            if (filterWheelEvent(event->u.u.detail)) {
-                emitButtonSignal("buttonRelease", event);
-            }
-            break;
-        case KeyPress:
-            updateModifier(event, true);
-            emitKeySignal("keyPress", event);
-            break;
-        case KeyRelease:
-            updateModifier(event, false);
-            emitKeySignal("keyRelease", event);
+//        case ButtonPress:
+//            if (filterWheelEvent(event->u.u.detail)) {
+//                emitButtonSignal("buttonPress", event);
+//            }
+//            break;
+//        case MotionNotify:
+//            emitButtonSignal("buttonDrag", event);
+//            break;
+//        case ButtonRelease:
+//            if (filterWheelEvent(event->u.u.detail)) {
+//                emitButtonSignal("buttonRelease", event);
+//            }
+//            break;
+//        case KeyPress:
+//            updateModifier(event, true);
+//            emitKeySignal("keyPress", event);
+//            break;
+        case XI_KeyRelease:
+//            updateModifier(event, false);
+//            emitKeySignal("keyRelease", event);
+            QMetaObject::invokeMethod(q_ptr, "keyRelease",
+                                      Qt::AutoConnection,
+                                      Q_ARG(int, event->u.u.detail));
             break;
         default:
             break;
