@@ -1,7 +1,7 @@
 /* -*- Mode: C++; indent-tabs-mode: nil; tab-width: 4 -*-
  * -*- coding: utf-8 -*-
  *
- * Copyright (C) 2020 KylinSoft Co., Ltd.
+ * Copyright (C) 2023 KylinSoft Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,7 +42,8 @@ PluginManager*  manager = nullptr;
 void handler(int no)
 {
     USD_LOG(LOG_DEBUG,"catch SIGTERM signal, with exitcode %d",no);
-//    manager->managerStop();
+    if (manager)
+        manager->managerStop();
     QApplication::exit(15);
 }
 
@@ -66,13 +67,12 @@ int main (int argc, char* argv[])
     QApplication::setQuitOnLastWindowClosed(false);
 
     QTranslator translator;
-    if(translator.load(QLocale(),QLatin1String("/usr/share/ukui-settings-daemon/daemon/res/i18n/"))) {
+    if (translator.load(QLocale(), "ukui-settings-daemon", "_", QM_FILES_INSTALL_PATH))
         app.installTranslator(&translator);
-    } else {
-        qDebug() << "zh_CH translator error!";
+    else {
+        USD_LOG(LOG_DEBUG, "Load translations file %s failed", QLocale::system().name().toLatin1().data());
     }
-    //translator.load("/usr/share/ukui-settings-daemon/daemon/res/i18n/zh_CN.qm");
-    //app.installTranslator(&translator);
+
     parse_args (argc, argv);
 
     if (replace) stop_daemon ();
@@ -84,7 +84,7 @@ int main (int argc, char* argv[])
 
     bool res = manager->managerStart();
     if (!res) {
-         USD_LOG(LOG_INFO, "manager start error!");
+//         USD_LOG(LOG_INFO, "manager start error!");
         return 0;
     }
 
@@ -131,6 +131,7 @@ static void stop_daemon ()
         // close current
         PluginManagerDBus pmd(ukuiDaemonBusName, ukuiDaemonBusPath, QDBusConnection::sessionBus());
         QDBusPendingReply<> reply = pmd.managerStop();
+        sleep(2);
         reply.waitForFinished();
         if (reply.isValid()) {
             //USD_LOG(LOG_DEBUG, "stop current 'ukui-settings-daemon'");
