@@ -1,7 +1,7 @@
 /* -*- Mode: C++; indent-tabs-mode: nil; tab-width: 4 -*-
  * -*- coding: utf-8 -*-
  *
- * Copyright (C) 2020 KylinSoft Co., Ltd.
+ * Copyright (C) 2023 KylinSoft Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 
 #include <QDebug>
 #include <QFile>
-
+#include <QVariant>
 PluginInfo::PluginInfo(QString& fileName)
 {
     int         priority;
@@ -150,6 +150,7 @@ bool PluginInfo::pluginActivate()
 
     if (!mAvailable) {USD_LOG(LOG_DEBUG, "plugin is not available!") return false;}
     if (mActive) {USD_LOG(LOG_DEBUG, "plugin has activity!") return true;}
+    if (!mEnabled) {USD_LOG(LOG_DEBUG, "plugin has disable!") return true;}
 
     // load module
     if (nullptr == mPlugin) {
