@@ -1,7 +1,7 @@
 /* -*- Mode: C++; indent-tabs-mode: nil; tab-width: 4 -*-
  * -*- coding: utf-8 -*-
  *
- * Copyright (C) 2020 KylinSoft Co., Ltd.
+ * Copyright (C) 2023 KylinSoft Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,6 +22,8 @@
 #include "plugin-interface.h"
 #include "autoBrightness-manager.h"
 #include "clib-syslog.h"
+#include "brightThread.h"
+
 class AutoBrightnessPlugin : public PluginInterface
 {
 private:
@@ -36,8 +38,8 @@ public:
     virtual void deactivate();
 
 private:
-    static AutoBrightnessManager    *mAutoBrightnessManager;
-    static PluginInterface      *mInstance;
+    static AutoBrightnessManager    *m_autoBrightnessManager;
+    static PluginInterface      *m_instance;
 };
 extern "C" Q_DECL_EXPORT PluginInterface *createSettingsPlugin();
 
