@@ -1,7 +1,7 @@
 /* -*- Mode: C++; indent-tabs-mode: nil; tab-width: 4 -*-
  * -*- coding: utf-8 -*-
  *
- * Copyright (C) 2020 KylinSoft Co., Ltd.
+ * Copyright (C) 2023 KylinSoft Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 #include <QDBusInterface>
 #include <QDBusArgument>
 #include <color-info.h>
-
+#include <QThread>
 #include "color-manager.h"
 
 #define PLUGIN_COLOR_SCHEMA         "org.ukui.SettingsDaemon.plugins.color"
@@ -36,7 +36,16 @@
 #define COLOR_KEY_AUTOMATIC_TO      "night-light-schedule-automatic-to"
 #define COLOR_KEY_FROM              "night-light-schedule-from"
 #define COLOR_KEY_TO                "night-light-schedule-to"
+#define COLOR_KEY_ACTIVE            "active"
+#define COLOR_KEY_DARK_MODE         "dark-mode"
+#define COLOR_KEY_ENABLED_DM        "night-light-enabled-dm"
+#define COLOR_KEY_ALLDAY_DM         "night-light-allday-dm"
+#define COLOR_KEY_AUTOMATIC_DM      "night-light-schedule-automatic-dm"
+#define COLOR_KEY_STYLE_NAME_DM     "style-name-dm"
+#define COLOR_KEY_REAL_TIME_TEMPERATURE "real-time-temperature"
+#define HAD_SET_EDU                  "had-set-edu"
 
+#define COLOR_KEY_AUTO_THEME_DM     "theme-schedule-automatic-dm"
 #define GTK_THEME_SCHEMA            "org.mate.interface"
 #define GTK_THEME_KEY               "gtk-theme"
 
@@ -80,20 +89,25 @@ ColorManager::ColorManager()
 {
     forced = false;
     smooth_id = 0;
+    m_darkModeChangedBySelf = false;
     smooth_timer = nullptr;
     disabled_until_tmw = false;
     datetime_override = NULL;
     geoclue_enabled = true;
     smooth_enabled  = true;
-    cached_sunrise  = -1.f;
-    cached_sunset   = -1.f;
+
     cached_temperature = USD_COLOR_TEMPERATURE_DEFAULT;
     settings = new QGSettings (PLUGIN_COLOR_SCHEMA);
+    cached_sunrise  = settings->get(COLOR_KEY_AUTOMATIC_TO).toDouble();
+    cached_sunset   = settings->get(COLOR_KEY_AUTOMATIC_FROM).toDouble();
     gtk_settings = new QGSettings (GTK_THEME_SCHEMA);
     qt_settings = new QGSettings (QT_THEME_SCHEMA);
-    mColorState    = new ColorState();
-    mColorProfiles = new ColorProfiles();
     m_NightChecktimer  = new QTimer(this);
+    m_stopServiceTimer = new QTimer(this);
+    m_stopServiceTimer->setSingleShot(true);
+    connect(m_stopServiceTimer, SIGNAL(timeout()), this, SLOT(doStopServerTimer()));
+    stopService();
+    mColorGtkConfig = new UkuiGtkConfig();
 }
 
 ColorManager::~ColorManager()
@@ -122,6 +136,10 @@ ColorManager::~ColorManager()
         delete mColorProfiles;
         mColorProfiles = nullptr;
     }
+    if (mColorGtkConfig) {
+        delete mColorGtkConfig;
+        mColorGtkConfig = nullptr;
+    }
 }
 
 ColorManager *ColorManager::ColorManagerNew()
@@ -148,6 +166,8 @@ bool ColorManager::NightLightSmoothCb (ColorManager *manager)
         if (frac >= 1.f) {
                 manager->NightLightSetTemperatureInternal (manager->smooth_target_temperature);
                 manager->smooth_id = 0;
+
+                USD_LOG(LOG_DEBUG,"set Temp...%f == %f",tmp,manager->smooth_target_temperature);
                 return G_SOURCE_REMOVE;
         }
 
@@ -180,11 +200,19 @@ void ColorManager::PollSmoothDestroy ()
 
 void ColorManager::NightLightSetTemperatureInternal (double temperature)
 {
-    if (ABS (cached_temperature - temperature) <= USD_TEMPERATURE_MAX_DELTA) {
+    if (ABS(cached_temperature - temperature) <= USD_TEMPERATURE_MAX_DELTA) {
 //        USD_LOG(LOG_DEBUG,"set night light %f error ABS:%f delta:%f", temperature,ABS (cached_temperature - temperature),USD_TEMPERATURE_MAX_DELTA);
+        if (cached_temperature != temperature) {
+            cached_temperature = temperature;
+            USD_LOG(LOG_DEBUG,".");
+            stopService();
+        }
         return;
     }
-
+    if (mColorState == nullptr) {
+        startService();
+    }
+    settings->set(COLOR_KEY_REAL_TIME_TEMPERATURE,temperature);
     cached_temperature = temperature;
     mColorState->ColorStateSetTemperature (cached_temperature);
 }
@@ -348,32 +376,39 @@ bool ColorManager::UpdateCachedSunriseSunset()
     double sunset;
     g_autoptr(GVariant) tmp = NULL;
     g_autoptr(GDateTime) dt_now = NightLightGetDateTimeNow ();
-
     GSettings *setting = g_settings_new(PLUGIN_COLOR_SCHEMA);
+
     /* calculate the sunrise/sunset for the location */
     tmp = g_settings_get_value (setting, COLOR_KEY_LAST_COORDINATES);
+
     g_clear_object(&setting);
 
     g_variant_get (tmp, "(dd)", &latitude, &longitude);
+
     if (latitude > 90.f || latitude < -90.f)
             return false;
     if (longitude > 180.f || longitude < -180.f)
             return false;
     if (!NightLightGetSunriseSunset (dt_now, latitude, longitude,
                                                &sunrise, &sunset)) {
-            qWarning ("failed to get sunset/sunrise for %.3f,%.3f",
+             USD_LOG(LOG_DEBUG,"failed to get sunset/sunrise for %.3f,%.3f",
                        longitude, longitude);
             return false;
     }
-
+//    USD_LOG(LOG_DEBUG," get sunset/sunrise for %.3f,%.3f,%.3f~%.3f",
+//              longitude, longitude,cached_sunset,cached_sunrise);
     /* anything changed */
     if (ABS (cached_sunrise - sunrise) > USD_FRAC_DAY_MAX_DELTA) {
             cached_sunrise = sunrise;
             ret = true;
+            settings->set(COLOR_KEY_AUTOMATIC_TO, cached_sunrise);
+            USD_LOG(LOG_DEBUG,"set cached_sunrise..%f.",cached_sunrise);
     }
     if (ABS (cached_sunset - sunset) > USD_FRAC_DAY_MAX_DELTA) {
         cached_sunset = sunset;
         ret = true;
+        settings->set(COLOR_KEY_AUTOMATIC_FROM, cached_sunset);
+        USD_LOG(LOG_DEBUG,"set cached_sunset..%f.",cached_sunset);
     }
     return ret;
 }
@@ -415,8 +450,9 @@ bool ColorManager::ReadKwinColorTempConfig()
     for (ColorInfo it : nightColor) {
         mNightConfig.insert(it.arg, it.out.variant());
     }
-
-    settings->set(COLOR_KEY_TEMPERATURE, mNightConfig[KWIN_NIGHT_TEMP].toInt());
+    if (mNightConfig[KWIN_NIGHT_TEMP].toInt() > 4000 &&  mNightConfig[KWIN_NIGHT_TEMP].toInt() < 6500) {
+        settings->set(COLOR_KEY_TEMPERATURE, mNightConfig[KWIN_NIGHT_TEMP].toInt());
+    }
     settings->set(COLOR_KEY_ENABLED,mNightConfig[KWIN_COLOR_ACTIVE].toBool());
 
     if (3 == mNightConfig[KWIN_COLOR_MODE].toInt()) {
@@ -443,10 +479,21 @@ bool ColorManager::ReadKwinColorTempConfig()
     mNightConfig[KWIN_NIGHT_TEMP] = mNightConfig[KWIN_CURRENT_TEMP];
     mNightConfig[KWIN_COLOR_ACTIVE] = false;
     colorIft.call("setNightColorConfig", mNightConfig);
-//    USD_LOG(LOG_DEBUG,".");
     return true;
 }
 
+void ColorManager::checkTempWarmAndTheme()
+{
+    bool allDay = settings->get(COLOR_KEY_ALLDAY).toBool();
+    bool enable = settings->get(COLOR_KEY_ENABLED).toBool();
+    QString theme = qt_settings->get(QT_THEME_KEY).toString();
+    if (allDay && enable && theme == "ukui-dark") {
+        m_darkModeChangedBySelf = true;
+        settings->set(COLOR_KEY_DARK_MODE, true);
+        settings->apply();
+    }
+}
+
 void ColorManager::NightLightRecheck(ColorManager *manager)
 {
     double frac_day;
@@ -465,41 +512,30 @@ void ColorManager::NightLightRecheck(ColorManager *manager)
     if (manager->forced) {
         temperature = manager->settings->get(COLOR_KEY_TEMPERATURE).toUInt();
         manager->NightLightSetTemperature (temperature);
-        USD_LOG(LOG_DEBUG,"set color to :%d",temperature);
+        USD_LOG(LOG_DEBUG,"return .......");
         return;
     }
 
+     manager->m_getGeoclueSuccess = manager->UpdateCachedSunriseSunset();//不需要每次进行计算，经纬度更换后才需要进行计算
+
     /* calculate the position of the sun */
     if (manager->settings->get(COLOR_KEY_AUTO_THEME).toBool()) {
-        manager->UpdateCachedSunriseSunset ();
-//        if (manager->cached_sunrise > 0.f && manager->cached_sunset > 0.f) {
-//            theme_to   = manager->cached_sunrise;
-//            theme_from = manager->cached_sunset;
-//        } else {
-//            theme_to = 7.0;
-//            theme_from = 18.0;
-//        }
-        theme_to = 7.0;
-        theme_from = 18.0;
+
+        theme_to = manager->settings->get(COLOR_KEY_AUTOMATIC_TO).toDouble();
+        theme_from = manager->settings->get(COLOR_KEY_AUTOMATIC_FROM).toDouble();
+
         /* get the current hour of a day as a fraction */
         frac_day = NightLightFracDayFromDt (dt_now);
-
-        if(frac_day > theme_to && frac_day < theme_from)
-            theme_now = 0;
-        else
-            theme_now = 1;
-
-        if(theme_now) {//需要根据项目进行设置
-            manager->gtk_settings->set(GTK_THEME_KEY, "ukui-black-unity");
+        if (NightLightFracDayIsBetween (frac_day, theme_from, theme_to)) {
+            manager->gtk_settings->set(GTK_THEME_KEY, "ukui-black");
             manager->qt_settings->set(QT_THEME_KEY, "ukui-dark");
         } else {
-            manager->gtk_settings->set(GTK_THEME_KEY, "ukui-white-unity");
+            manager->gtk_settings->set(GTK_THEME_KEY, "ukui-white");
             manager->qt_settings->set(QT_THEME_KEY, "ukui-light");
         }
     }
 
     if(!manager->settings->get(COLOR_KEY_ENABLED).toBool()){
-        USD_LOG(LOG_DEBUG, "stop it..");
         manager->NightLightSetActive (false);
         return;
     }
@@ -507,23 +543,25 @@ void ColorManager::NightLightRecheck(ColorManager *manager)
     if(manager->settings->get(COLOR_KEY_ALLDAY).toBool()){
         temperature = manager->settings->get(COLOR_KEY_TEMPERATURE).toUInt();
         manager->NightLightSetTemperature (temperature);
-        USD_LOG(LOG_DEBUG,"COLOR_KEY_ALLDAY temperature:%d",temperature);
+
         return;
     }
 
     /* calculate the position of the sun */
     if (manager->settings->get(COLOR_KEY_AUTOMATIC).toBool()) {
-        manager->UpdateCachedSunriseSunset ();
         if (manager->cached_sunrise > 0.f && manager->cached_sunset > 0.f) {
             schedule_to   = manager->cached_sunrise;
             schedule_from = manager->cached_sunset;
-            manager->settings->set(COLOR_KEY_AUTOMATIC_FROM, 18.00);
-            manager->settings->set(COLOR_KEY_AUTOMATIC_TO, 7.00);
+            manager->settings->set(COLOR_KEY_AUTOMATIC_FROM, schedule_from);
+            manager->settings->set(COLOR_KEY_AUTOMATIC_TO, schedule_to);
+        } else {
+            schedule_from = manager->settings->get(COLOR_KEY_AUTOMATIC_FROM).toDouble();
+            schedule_to = manager->settings->get(COLOR_KEY_AUTOMATIC_TO).toDouble();
         }
     }
 
     /* fall back to manual settings */
-    if (schedule_to <= 0.f || schedule_from <= 0.f) {
+    if (schedule_to < 0.f || schedule_from < 0.f) {
         schedule_from = manager->settings->get(COLOR_KEY_FROM).toDouble();
         schedule_to = manager->settings->get(COLOR_KEY_TO).toDouble();
     }
@@ -600,20 +638,22 @@ void ColorManager::NightLightRecheck(ColorManager *manager)
         double factor = 1.f - ((frac_day - (schedule_from - smear)) / smear);
         temp_smeared = LinearInterpolate (USD_COLOR_TEMPERATURE_DEFAULT,
                                           temperature, factor);
+        USD_LOG(LOG_DEBUG,"val1:%d val2:%d factor:%f,frac_day:%f,schedule_from:%f",USD_COLOR_TEMPERATURE_DEFAULT, temperature, factor,
+                frac_day,schedule_from);
     } else if (NightLightFracDayIsBetween (frac_day,
                                            schedule_to - smear,
                                            schedule_to)) {
         double factor = (frac_day - (schedule_to - smear)) / smear;
         temp_smeared = LinearInterpolate (USD_COLOR_TEMPERATURE_DEFAULT,
                                           temperature, factor);
+        USD_LOG(LOG_DEBUG,"val1:%d val2:%d factor:%f,frac_day:%d,schedule_from:%d",USD_COLOR_TEMPERATURE_DEFAULT, temperature, factor,
+                frac_day,schedule_from);
     } else {
         temp_smeared = temperature;
     }
-//    //qDebug("night light mode on, using temperature of %uK (aiming for %uK)",
-//         temp_smeared, temperature);
+    USD_LOG(LOG_DEBUG,"temp_smeared:%d ...%d", temp_smeared, USD_COLOR_TEMPERATURE_DEFAULT-temp_smeared);
     manager->NightLightSetActive (true);
     manager->NightLightSetTemperature (temp_smeared);
-    USD_LOG(LOG_DEBUG,"set temp :%d",temp_smeared);
 }
 
 void ColorManager::OnLocationNotify(GClueSimple *simple,
@@ -636,8 +676,13 @@ void ColorManager::OnLocationNotify(GClueSimple *simple,
     // //qDebug("got geoclue latitude %f, longitude %f", latitude, longitude);
 
     /* recheck the levels if the location changed significantly */
-    if (manager->UpdateCachedSunriseSunset ())
-           manager->NightLightRecheck (manager);
+    if (manager->UpdateCachedSunriseSunset ()) {
+        manager->NightLightRecheck (manager);
+    }
+
+//    USD_LOG(LOG_DEBUG,"set latitude:%f  longitude:%f,%f-%f", latitude, longitude,manager->cached_sunset,manager->cached_sunrise);
+   //获取成功一次后停止服务。。
+    manager->stopService();
 }
 void ColorManager::OnGeoclueSimpleReady(GObject *source_object,
                                         GAsyncResult *res,
@@ -650,7 +695,7 @@ void ColorManager::OnGeoclueSimpleReady(GObject *source_object,
     geoclue_simple = gclue_simple_new_finish (res, &error);
     if (geoclue_simple == NULL) {
             if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-                    qWarning ("Failed to connect to GeoClue2 service: %s", error->message);
+                     USD_LOG(LOG_DEBUG,"Failed to connect to GeoClue2 service: %s", error->message);
             return;
     }
 
@@ -687,40 +732,237 @@ void ColorManager::StopGeoclue()
     g_clear_object (&geoclue_simple);
 }
 
+void ColorManager::startService()
+{
+        QDBusInterface iface("com.settings.daemon.qt.systemdbus", \
+                             "/", \
+                             "com.settings.daemon.interface", \
+                             QDBusConnection::systemBus());
+        if (iface.isValid()) {
+            iface.call("startColorService");
+            USD_LOG(LOG_DEBUG,"start geoclue");
+        }
+        USD_LOG(LOG_DEBUG,"start ...");
+
+        QThread::msleep(200);
+        if(mColorState ==nullptr) {
+            mColorState    = new ColorState();
+        }
+        if (mColorProfiles == nullptr) {
+            mColorProfiles = new ColorProfiles();
+        }
+        StartGeoclue();
+        mColorProfiles->ColorProfilesStart();
+        mColorState->ColorStateStart();
+        NightLightRecheck(this);
+
+}
+
+void ColorManager::stopService()
+{
+    m_stopServiceTimer->start(10000);
+}
+
+bool ColorManager::getNetworkState()
+{
+    QDBusInterface iface("org.freedesktop.NetworkManager", \
+                         "/org/freedesktop/NetworkManager", \
+                         "org.freedesktop.NetworkManager", \
+                         QDBusConnection::systemBus());
+
+    if (iface.isValid()) {
+      USD_LOG(LOG_DEBUG,"network state:%d",iface.property("State").toInt());
+    } else {
+       USD_LOG(LOG_DEBUG,"network state:xx!!");
+    }
+
+}
+
 void ColorManager::SettingsChangedCb(QString key)
 {
-//    //qDebug("settings changed");
+    bool darkMode = settings->get(COLOR_KEY_DARK_MODE).toBool();
+    bool ret;
+    if (key.contains("-dm") || key == COLOR_KEY_REAL_TIME_TEMPERATURE) {
+        return;
+    }
+
+    //外部修改，则直接退出夜间模式。
+    if (key == COLOR_KEY_ALLDAY || key == COLOR_KEY_ENABLED) {
+        ret = settings->get(key).toBool();
+        if (darkMode && false == ret) {
+            m_darkModeChangedBySelf = true;
+            settings->set(COLOR_KEY_DARK_MODE,false);
+            settings->apply();
+        }
+        USD_LOG(LOG_DEBUG, "=============>key:%s:%d,dm:%d",key.toLatin1().data(),ret,darkMode);
+    } else if (key == COLOR_KEY_AUTOMATIC) {
+        ret = settings->get(key).toBool();
+        if (darkMode && true == ret) {
+            m_darkModeChangedBySelf = true;
+            settings->set(COLOR_KEY_DARK_MODE,false);
+            settings->apply();
+        }
+         USD_LOG(LOG_DEBUG, "=============>key:%s:%d,dm:%d",key.toLatin1().data(),ret,darkMode);
+    } else if (key == COLOR_KEY_AUTO_THEME) {
+        ret = settings->get(key).toBool();
+        if (darkMode && true == ret) {
+            m_darkModeChangedBySelf = true;
+            settings->set(COLOR_KEY_DARK_MODE,false);
+            settings->apply();
+        }
+        USD_LOG(LOG_DEBUG, "=============>key:%s:%d,dm:%d",key.toLatin1().data(),ret,darkMode);
+    }
+
+    if (key == COLOR_KEY_DARK_MODE) {
+        if (m_darkModeChangedBySelf) {
+            USD_LOG(LOG_DEBUG, "skip it....");
+            m_darkModeChangedBySelf = false;
+            return;
+        }
+        if (settings->get(key).toBool()) {//进入夜间模式
+            settings->delay();
+            settings->set(COLOR_KEY_ALLDAY_DM, settings->get(COLOR_KEY_ALLDAY).toBool());
+            settings->set(COLOR_KEY_ENABLED_DM, settings->get(COLOR_KEY_ENABLED).toBool());
+            settings->set(COLOR_KEY_AUTOMATIC_DM, settings->get(COLOR_KEY_AUTOMATIC).toBool());
+            settings->set(COLOR_KEY_STYLE_NAME_DM, qt_settings->get(QT_THEME_KEY).toString());
+            settings->set(COLOR_KEY_AUTO_THEME_DM, settings->get(COLOR_KEY_AUTO_THEME).toString());//四个任意一个改变则退出夜间模式。
+
+            settings->set(COLOR_KEY_ALLDAY, true);
+            settings->set(COLOR_KEY_ENABLED, true);
+            settings->set(COLOR_KEY_AUTOMATIC, false);
+
+            settings->set(COLOR_KEY_AUTO_THEME, false);
+            qt_settings->set(QT_THEME_KEY, "ukui-dark");
+            gtk_settings->set(GTK_THEME_KEY, "ukui-black");
+            settings->apply();
+            USD_LOG(LOG_DEBUG, "enter dark mode");
+        } else {//退出夜间模式1
+            settings->delay();
+            settings->set(COLOR_KEY_ALLDAY, settings->get(COLOR_KEY_ALLDAY_DM).toBool());
+            settings->set(COLOR_KEY_ENABLED, settings->get(COLOR_KEY_ENABLED_DM).toBool());
+            settings->set(COLOR_KEY_AUTOMATIC, settings->get(COLOR_KEY_AUTOMATIC_DM).toBool());
+            settings->set(COLOR_KEY_AUTO_THEME, settings->get(COLOR_KEY_AUTO_THEME_DM).toBool());
+
+            if (false == settings->get(COLOR_KEY_AUTO_THEME).toBool()) {
+                if (settings->get(COLOR_KEY_STYLE_NAME_DM).toString() == "ukui-default") {
+                    qt_settings->set(QT_THEME_KEY, "ukui-default");
+                    gtk_settings->set(GTK_THEME_KEY, "ukui-white");
+                } else if(settings->get(COLOR_KEY_STYLE_NAME_DM).toString() == "ukui-light"){
+                    qt_settings->set(QT_THEME_KEY, "ukui-light");
+                    gtk_settings->set(GTK_THEME_KEY, "ukui-white");
+                } else {
+                    qt_settings->set(QT_THEME_KEY, "ukui-dark");
+                    gtk_settings->set(GTK_THEME_KEY, "ukui-black");
+                }
+            } else {
+
+            }
+            settings->apply();
+            USD_LOG(LOG_DEBUG, "exit dark mode");
+        }
+    }
+
     if(key == COLOR_KEY_AUTOMATIC_FROM || key == COLOR_KEY_AUTOMATIC_TO){
+        USD_LOG(LOG_DEBUG,"KEY:%s",key.toLatin1().data());
+        NightLightRecheck(this);
         return;
     }
 
     USD_LOG(LOG_DEBUG,"KEY:%s",key.toLatin1().data());
 
+    if (key == COLOR_KEY_ACTIVE) {
+        USD_LOG(LOG_DEBUG,"get active.");
+        if (!settings->get(key).toBool()) {
+            if (mColorState) {
+                delete mColorState;
+                mColorState = nullptr;
+            }
+            if (mColorProfiles) {
+                delete mColorProfiles;
+                mColorProfiles = nullptr;
+            }
+            USD_LOG(LOG_DEBUG,".");
+            stopService();
+        }
+        return;
+    }
+
+//    USD_LOG(LOG_DEBUG,"KEY:%s",key.toLatin1().data());
+
     NightLightRecheck(this);
-    mColorState->ColorStateSetTemperature (cached_temperature);
+    if (cached_temperature == USD_COLOR_TEMPERATURE_DEFAULT) {
+        if (mColorState == nullptr) {
+            startService();
+            QThread::msleep(300);
+        }
+        mColorState->ColorStateSetTemperature (cached_temperature);
+    } else {
+        if (mColorState == nullptr) {
+            startService();
+        }
+        mColorState->ColorStateSetTemperature (cached_temperature);
+    }
+
+}
+
+void ColorManager::qtSetingsChangedCb(QString key)
+{
+    if (key == QT_THEME_KEY) {
+        if (qt_settings->get(key).toString() != "ukui-dark") {
+            if (settings->get(COLOR_KEY_DARK_MODE).toBool()) {
+                m_darkModeChangedBySelf = true;
+                settings->set(COLOR_KEY_STYLE_NAME_DM, qt_settings->get(QT_THEME_KEY).toString());
+                settings->set(COLOR_KEY_DARK_MODE,false);
+                settings->apply();
+            }
+        }
+        checkTempWarmAndTheme();
+    }
 }
 
 bool ColorManager::ColorManagerStart()
 {
     USD_LOG(LOG_DEBUG,"--Color manager start--");
     int ms = 2000;
-    if (false == ReadKwinColorTempConfig()) {
+
+    if (UsdBaseClass::isEdu())
+    {
+        if (!settings->get(HAD_SET_EDU).toBool()) {
+            settings->set(COLOR_KEY_TEMPERATURE, 5150);
+            settings->set(COLOR_KEY_ALLDAY, true);
+            settings->set(COLOR_KEY_AUTOMATIC, false);
+            settings->set(COLOR_KEY_TEMPERATURE, 5150);
+            settings->set(HAD_SET_EDU,true);
+             USD_LOG(LOG_DEBUG,"--edu first  start--");
+        }
         ms = 100;
+        USD_LOG(LOG_DEBUG,"--Color edu start--");
+    }
+
+    if (!settings->get(HAD_READ_KWIN).toBool()){
+        if (false == ReadKwinColorTempConfig()) {
+            ms = 100;
+        }
     }
 
     QTimer::singleShot(ms, this, [=](){
-        mColorProfiles->ColorProfilesStart();
-        mColorState->ColorStateStart();
-        NightLightRecheck(this);
         connect(m_NightChecktimer, SIGNAL(timeout()), this, SLOT(checkTime()));
         m_NightChecktimer->start(USD_NIGHT_LIGHT_POLL_TIMEOUT*1000);
-        StartGeoclue();
         connect(settings,SIGNAL(changed(QString)),this,SLOT(SettingsChangedCb(QString)));
+        SettingsChangedCb(COLOR_KEY_ENABLED);
+        m_pNetworkBus = new QDBusInterface("org.freedesktop.NetworkManager", \
+                                  "/org/freedesktop/NetworkManager", \
+                                  "org.freedesktop.NetworkManager", \
+                                  QDBusConnection::systemBus());
+
+        if (m_pNetworkBus->property("State").toInt() == 70) {
+            USD_LOG(LOG_DEBUG,"network connect success");
+            startService();
+            StartGeoclue();
+        } else {
+            connect(m_pNetworkBus, SIGNAL(StateChanged(uint)), this, SLOT(doNetworkStateCanged(uint)));
+        }
     });
-
-
-
-
     return  true;
 }
 
@@ -729,6 +971,40 @@ void ColorManager::checkTime()
     NightLightRecheck (this);
 }
 
+void ColorManager::doStopServerTimer()
+{
+        QDBusInterface iface("com.settings.daemon.qt.systemdbus", \
+                             "/", \
+                             "com.settings.daemon.interface", \
+                             QDBusConnection::systemBus());
+
+        if (iface.isValid()) {
+            iface.call("stopColorService");
+            USD_LOG(LOG_DEBUG,"stopService");
+        }
+
+        QThread::msleep(200);
+        if (mColorState) {
+            delete mColorState;
+            mColorState = nullptr;
+        }
+        if (mColorProfiles) {
+            delete mColorProfiles;
+            mColorProfiles = nullptr;
+        }
+        USD_LOG(LOG_DEBUG,"stop ...");
+}
+
+void ColorManager::doNetworkStateCanged(uint state)
+{
+    if (m_lastNetworkState != state && state == 70) {
+        m_lastNetworkState = state;
+        USD_LOG(LOG_DAEMON,"network had ready");
+        startService();
+        StartGeoclue();
+    }
+}
+
 void ColorManager::ColorManagerStop()
 {
     USD_LOG(LOG_DEBUG,"Color manager stop");
