@@ -1,7 +1,7 @@
 /* -*- Mode: C++; indent-tabs-mode: nil; tab-width: 4 -*-
  * -*- coding: utf-8 -*-
  *
- * Copyright (C) 2020 KylinSoft Co., Ltd.
+ * Copyright (C) 2023 KylinSoft Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,9 +24,10 @@
 #include <QTimer>
 #include <glib.h>
 #include <geoclue.h>
-
+#include <QDBusInterface>
 #include "color-state.h"
 #include "color-profiles.h"
+#include "color-gtkconfig.h"
 
 #define USD_COLOR_TEMPERATURE_MIN               1000    /* Kelvin */
 #define USD_COLOR_TEMPERATURE_DEFAULT           6500    /* Kelvin, is RGB [1.0,1.0,1.0] */
@@ -66,14 +67,23 @@ public:
     void NightLightSetActive(bool active);
     bool UpdateCachedSunriseSunset();
     bool ReadKwinColorTempConfig();
-
+    void checkTempWarmAndTheme();
 public Q_SLOTS:
-    void SettingsChangedCb(QString);
+    void SettingsChangedCb(QString key);
+    void qtSetingsChangedCb(QString key);
     void checkTime();
+    void doStopServerTimer();
+    void doNetworkStateCanged(uint state);
+private :
+    void startService();
+    void stopService();
+    bool getNetworkState();
 private:
     static ColorManager *mColorManager;
-    ColorProfiles       *mColorProfiles;
-    ColorState          *mColorState;
+    ColorProfiles       *mColorProfiles = nullptr;
+    ColorState          *mColorState = nullptr;
+
+    UkuiGtkConfig       *mColorGtkConfig;
 
     QGSettings *settings;
     QGSettings *gtk_settings;
@@ -87,16 +97,22 @@ private:
     double      cached_sunset;
     double      cached_temperature;
     bool        disabled_until_tmw;
+    bool        m_darkModeChangedBySelf;
     GDateTime  *disabled_until_tmw_dt;
     GDateTime  *datetime_override;
     GTimer     *smooth_timer;
     QTimer      *m_NightChecktimer;
+    QTimer      *m_stopServiceTimer;
     guint       smooth_id;
     double      smooth_target_temperature;
     GCancellable  *cancellable;
     GClueClient   *geoclue_client;
     GClueSimple   *geoclue_simple;
     QHash<QString, QVariant> mNightConfig;
+    QDBusInterface *m_pNetworkBus = nullptr;
+    int m_lastNetworkState = 0;
+    bool m_getGeoclueSuccess = false;
+
 };
 
 #endif // COLORMANAGER_H
