@@ -1,7 +1,7 @@
 /* -*- Mode: C++; indent-tabs-mode: nil; tab-width: 4 -*-
  * -*- coding: utf-8 -*-
  *
- * Copyright (C) 2020 KylinSoft Co., Ltd.
+ * Copyright (C) 2023 KylinSoft Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@
  */
 #include "color-state.h"
 #include "config.h"
+#include <QDBusConnection>
 
 typedef struct {
         guint32          red;
@@ -70,7 +71,7 @@ ColorState::~ColorState()
     g_cancellable_cancel (cancellable);
     g_clear_object (&cancellable);
     g_clear_object (&client);
-    g_clear_pointer (&edid_cache, g_hash_table_destroy);
+    //g_clear_pointer (&edid_cache, g_hash_table_destroy);
     g_clear_pointer (&device_assign_hash, g_hash_table_destroy);
     g_clear_object (&state_screen);
 
@@ -91,7 +92,6 @@ void ColorState::ColorStateSetTemperature(guint temperature)
     if(temperature > USD_COLOR_TEMPERATURE_MAX)
         temperature = USD_COLOR_TEMPERATURE_MAX;
     color_temperature = temperature;
-    USD_LOG(LOG_DEBUG,"color_temperature %d",color_temperature);
     SessionSetGammaForAllDevices (this);
 }
 
@@ -195,7 +195,7 @@ SessionCreateDeviceCb (GObject *object,
                 if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED) &&
                     !g_error_matches (error, CD_CLIENT_ERROR, CD_CLIENT_ERROR_ALREADY_EXISTS))
                 {
-                        qWarning ("failed to create device: %s", error->message);
+                        USD_LOG(LOG_DEBUG,"failed to create device: %s", error->message);
                 }
                 g_error_free (error);
                 return;
@@ -226,7 +226,7 @@ void ColorState::SessionAddStateOutput (ColorState *state, MateRROutput *output)
         /* try to get edid */
         edid = SessionGetOutputEdid (state, output);
         if (edid == nullptr) {
-                qWarning ("failed to get edid:");
+                USD_LOG(LOG_DEBUG,"failed to get edid:");
         }
 
         /* prefer DMI data for the internal output */
@@ -414,7 +414,7 @@ bool ColorState::SessionDeviceResetGamma(MateRROutput *output,
         if (!cd_color_get_blackbody_rgb_full (color_temperature,
                                               &temp,
                                               CD_COLOR_BLACKBODY_FLAG_USE_PLANCKIAN)) {
-//                qWarning ("failed to get blackbody for %uK", color_temperature);
+//                USD_LOG(LOG_DEBUG,"failed to get blackbody for %uK", color_temperature);
                 cd_color_rgb_set (&temp, 1.0, 1.0, 1.0);
         }
 
@@ -517,13 +517,13 @@ bool ColorState::GetSystemIccProfile(ColorState *state,
                                     &error);
 
         if (!ret) {
-                qWarning ("failed to read EFI system color profile: %s",
+                USD_LOG(LOG_DEBUG,"failed to read EFI system color profile: %s",
                            error->message);
                 return false;
         }
 
         if (length <= efi_var_header_length) {
-                qWarning ("EFI system color profile was too short");
+                USD_LOG(LOG_DEBUG,"EFI system color profile was too short");
                 return false;
         }
 
@@ -537,7 +537,7 @@ bool ColorState::GetSystemIccProfile(ColorState *state,
                                        NULL /* cancellable */,
                                        &error);
         if (!ret) {
-                qWarning ("failed to write system color profile: %s",
+                USD_LOG(LOG_DEBUG,"failed to write system color profile: %s",
                            error->message);
                 return false;
         }
@@ -674,7 +674,7 @@ bool ColorState::SessionUseOutputProfileForScreen (ColorState *state,
         /* do we have any screens marked as primary */
         outputs = mate_rr_screen_list_outputs (state->state_screen);
         if (outputs == NULL || outputs[0] == NULL) {
-//                qWarning ("failed to get outputs");
+//                USD_LOG(LOG_DEBUG,"failed to get outputs");
                 return false;
         }
         for (i = 0; outputs[i] != NULL; i++) {
@@ -780,7 +780,7 @@ SessionGenerateVcgt (CdProfile *profile, guint color_temperature, guint size)
         if (!cd_color_get_blackbody_rgb_full (color_temperature,
                                               &temp,
                                               CD_COLOR_BLACKBODY_FLAG_USE_PLANCKIAN)) {
-//                qWarning ("failed to get blackbody for %uK", color_temperature);
+//                USD_LOG(LOG_DEBUG,"failed to get blackbody for %uK", color_temperature);
                 cd_color_rgb_set (&temp, 1.0, 1.0, 1.0);
         } else {
                 qDebug ("using VCGT gamma of %uK = %.1f,%.1f,%.1f",
@@ -853,7 +853,7 @@ void ColorState::SessionDeviceAssignProfileConnectCb (GObject *object,
         if (!ret) {
             if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
             {
-                qWarning ("failed to connect to profile: %s", error->message);
+                USD_LOG(LOG_DEBUG,"failed to connect to profile: %s", error->message);
             }
             g_error_free (error);
             goto out;
@@ -877,7 +877,7 @@ void ColorState::SessionDeviceAssignProfileConnectCb (GObject *object,
                                                   filename,
                                                   &error);
                 if (!ret) {
-                        qWarning ("failed to set screen _ICC_PROFILE: %s",
+                        USD_LOG(LOG_DEBUG,"failed to set screen _ICC_PROFILE: %s",
                                    error->message);
                         g_clear_error (&error);
                 }
@@ -890,7 +890,7 @@ void ColorState::SessionDeviceAssignProfileConnectCb (GObject *object,
                                              profile,
                                              state->color_temperature);
                 if (!ret) {
-                        qWarning ("failed to set %s gamma tables",
+                        USD_LOG(LOG_DEBUG,"failed to set %s gamma tables",
                                    cd_device_get_id (helper->device));
                         goto out;
                 }
@@ -898,7 +898,7 @@ void ColorState::SessionDeviceAssignProfileConnectCb (GObject *object,
                 ret = SessionDeviceResetGamma (output,
                                                state->color_temperature);
                 if (!ret) {
-                        qWarning ("failed to reset %s gamma tables",
+                        USD_LOG(LOG_DEBUG,"failed to reset %s gamma tables",
                                    cd_device_get_id (helper->device));
                         goto out;
                 }
@@ -935,7 +935,7 @@ void ColorState::SessionDeviceAssignConnectCb (GObject *object,
     if (!ret) {
         if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
         {
-                qWarning ("failed to connect to device: %s", error->message);
+                USD_LOG(LOG_DEBUG,"failed to connect to device: %s", error->message);
         }
         g_error_free (error);
         goto out;
@@ -953,14 +953,14 @@ void ColorState::SessionDeviceAssignConnectCb (GObject *object,
     output = SessionGetStateOutputById (state,
                                         xrandr_id);
     if (output == NULL) {
-        qWarning ("no %s device found", cd_device_get_id (device));
+        USD_LOG(LOG_DEBUG,"no %s device found", cd_device_get_id (device));
         goto out;
     }
 
     /* create profile from device edid if it exists */
     edid = SessionGetOutputEdid (state, output);
     if (edid == nullptr) {
-        qWarning ("unable to get EDID for %s", cd_device_get_id (device));
+        USD_LOG(LOG_DEBUG,"unable to get EDID for %s", cd_device_get_id (device));
     } else {
         autogen_filename = g_strdup_printf ("edid-%s.icc",
                                             edid->EdidGetChecksum ());
@@ -987,8 +987,12 @@ void ColorState::SessionDeviceAssignConnectCb (GObject *object,
                 }
 
                 if (!ret) {
-                        qWarning ("failed to create profile from EDID data: %s", error->message);
-                        g_clear_error (&error);
+                        if (error) {
+                            USD_LOG(LOG_DEBUG,"failed to create profile from EDID data: %s", error->message);
+                            g_clear_error (&error);
+                        } else {
+                            USD_LOG(LOG_DEBUG,"failed to create profile from EDID data: no reason");
+                        }
                 }
         }
     }
@@ -996,7 +1000,7 @@ void ColorState::SessionDeviceAssignConnectCb (GObject *object,
     /* get the default profile for the device */
     profile = cd_device_get_default_profile (device);
     if (profile == NULL) {
-        qDebug ("%s has no default profile to set", cd_device_get_id (device));
+//        qDebug ("%s has no default profile to set", cd_device_get_id (device));
 
         /* the default output? */
         if (mate_rr_output_get_is_primary (output) &&
@@ -1011,7 +1015,7 @@ void ColorState::SessionDeviceAssignConnectCb (GObject *object,
         ret = SessionDeviceResetGamma (output,
                                        state->color_temperature);
         if (!ret) {
-                qWarning ("failed to reset %s gamma tables", cd_device_get_id (device));
+                USD_LOG(LOG_DEBUG,"failed to reset %s gamma tables", cd_device_get_id (device));
                 goto out;
         }
         goto out;
@@ -1058,6 +1062,7 @@ void ColorState::SessionProfileGammaFindDeviceCb (GObject *object,
                                                            res,
                                                            &error);
         if (device == NULL) {
+            USD_LOG(LOG_DEBUG,"error : %s",error->message);
             if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED)){
                 USD_LOG(LOG_DEBUG,".");
             }
@@ -1075,7 +1080,7 @@ void ColorState::SessionProfileGammaFindDeviceCb (GObject *object,
         if (device != NULL)
                 g_object_unref (device);
 
-        USD_LOG(LOG_DEBUG,"set gamma over..");
+//        USD_LOG(LOG_DEBUG,"set gamma over..");
 }
 
 
@@ -1107,8 +1112,6 @@ void ColorState::SessionSetGammaForAllDevices (ColorState *state)
 //            if (mate_rr_output_is_laptop (outputs[i]))
 
             if (mate_rr_output_is_connected(outputs[i])){
-//                qDebug("Output Name %s\n", mate_rr_output_get_name (outputs[i]));
-
                 /* get CdDevice for this output */
                 cd_client_find_device_by_property (state->client,
                                                    CD_DEVICE_METADATA_XRANDR_NAME,
@@ -1116,7 +1119,6 @@ void ColorState::SessionSetGammaForAllDevices (ColorState *state)
                                                    state->cancellable,
                                                    SessionProfileGammaFindDeviceCb,
                                                    state);
-                continue;
             }
         }
 
@@ -1129,7 +1131,29 @@ void ColorState::SessionSetGammaForAllDevices (ColorState *state)
 void ColorState::MateRrScreenOutputChangedCb (MateRRScreen *screen,
                                               ColorState *state)
 {
-        SessionSetGammaForAllDevices (state);
+    //insert output list
+    MateRROutput **outputs;
+    /* get STATE outputs */
+    outputs = mate_rr_screen_list_outputs (state->state_screen);
+
+    if (outputs == NULL) {
+        USD_LOG(LOG_DEBUG,"failed to get outputs");
+        return;
+    }
+
+    for (int i = 0; outputs[i] != NULL; i++) {
+
+        if (UsdBaseClass::isTablet()) {
+            if (mate_rr_output_is_laptop (outputs[i])) {
+                 SessionAddStateOutput (state, outputs[i]);
+            }
+        } else {
+            if (mate_rr_output_is_connected(outputs[i])) {
+                SessionAddStateOutput (state, outputs[i]);
+            }
+        }
+    }
+    SessionSetGammaForAllDevices(state);
 }
 
 void ColorState::SessionDeviceAssign (ColorState *state, CdDevice *device)
@@ -1180,7 +1204,7 @@ void ColorState::SessionGetDevicesCb (GObject *object, GAsyncResult *res, gpoint
         array = cd_client_get_devices_finish (CD_CLIENT (object), res, &error);
         if (array == NULL) {
                 if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-                        qWarning ("failed to get devices: %s", error->message);
+                        USD_LOG(LOG_DEBUG,"failed to get devices: %s", error->message);
                 g_error_free (error);
                 return;
         }
@@ -1210,7 +1234,7 @@ void ColorState::SessionClientConnectCb (GObject *source_object,
 
     if (!ret) {
         if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
-            qWarning ("failed to connect to colord: %s", error->message);
+            USD_LOG(LOG_DEBUG,"failed to connect to colord: %s", error->message);
         }
         g_error_free (error);
         return;
@@ -1264,15 +1288,15 @@ void ColorState::SessionClientConnectCb (GObject *source_object,
     }
 
     /* only connect when colord is awake */
-    //    g_signal_connect (state->state_screen, "changed",
-    //                      G_CALLBACK (MateRrScreenOutputChangedCb),
-    //                      state);
-    //    g_signal_connect (state->client, "device-added",
-    //                      G_CALLBACK (SessionDeviceAddedAssignCb),
-    //                      state);
-    //    g_signal_connect (state->client, "device-changed",
-    //                      G_CALLBACK (SessionDeviceChangedAssignCb),
-    //                      state);
+        g_signal_connect (state->state_screen, "changed",
+                          G_CALLBACK (MateRrScreenOutputChangedCb),
+                          state);
+        g_signal_connect (state->client, "device-added",
+                          G_CALLBACK (SessionDeviceAddedAssignCb),
+                          state);
+        g_signal_connect (state->client, "device-changed",
+                          G_CALLBACK (SessionDeviceChangedAssignCb),
+                          state);
 
     /* set for each device that already exist */
     cd_client_get_devices (state->client,
@@ -1290,7 +1314,7 @@ bool ColorState::ColorStateStart()
     GError *error = NULL;
     state_screen = mate_rr_screen_new(gdk_screen_get_default (), &error);
     if (state_screen == NULL) {
-            qWarning ("failed to get screens: %s", error->message);
+            USD_LOG(LOG_DEBUG,"failed to get screens: %s", error->message);
             g_error_free (error);
             return false;
     }
