@@ -1,7 +1,7 @@
 /* -*- Mode: C++; indent-tabs-mode: nil; tab-width: 4 -*-
  * -*- coding: utf-8 -*-
  *
- * Copyright (C) 2020 KylinSoft Co., Ltd.
+ * Copyright (C) 2023 KylinSoft Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,7 +22,9 @@
 #include <QObject>
 #include <QDialog>
 #include <QLabel>
+#include <QScrollArea>
 #include <QPushButton>
+#include "QGSettings/qgsettings.h"
 
 namespace Ui {
 class LdsmTrashEmpty;
@@ -40,19 +42,22 @@ public:
 public Q_SLOTS:
     void checkButtonCancel();
     void checkButtonTrashEmpty();
-
+    void updateText(QString key);
+    void resetFont(QWidget *pWid, QString str);
 private:
     Ui::LdsmTrashEmpty *ui;
     QLabel *first_text;
     QLabel *second_text;
+    QScrollArea *second_text_area;
     QPushButton *trash_empty;
     QPushButton *cancel;
-
+    QGSettings* m_fontSetting;
 private:
     void windowLayoutInit();
     void connectEvent();
     void deleteContents(const QString path);
 
+
 };
 
 #endif // LDSMTRASHEMPTY_H
