@@ -1,7 +1,7 @@
 /* -*- Mode: C++; indent-tabs-mode: nil; tab-width: 4 -*-
  * -*- coding: utf-8 -*-
  *
- * Copyright (C) 2020 KylinSoft Co., Ltd.
+ * Copyright (C) 2023 KylinSoft Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 #include <QDebug>
 #include "qtimer.h"
 #include "syslog.h"
-
+#include "clib-syslog.h"
 
 #define GIGABYTE                   1024 * 1024 * 1024
 
@@ -38,7 +38,7 @@
 
 static guint64 *time_read;
 
-DIskSpace::DIskSpace()
+DiskSpace::DiskSpace()
 {
 
     ldsm_timeout_cb = new QTimer();
@@ -53,7 +53,7 @@ DIskSpace::DIskSpace()
     done = FALSE;
 
     connect(ldsm_timeout_cb, &QTimer::timeout,
-            this, &DIskSpace::ldsm_check_all_mounts);
+            this, &DiskSpace::ldsm_check_all_mounts);
 
     ldsm_timeout_cb->start();
 
@@ -63,7 +63,7 @@ DIskSpace::DIskSpace()
     this->dialog = nullptr;
 }
 
-DIskSpace::~DIskSpace()
+DiskSpace::~DiskSpace()
 {
     delete trash_empty;
     delete settings;
@@ -77,7 +77,7 @@ ldsm_ignore_path_compare (gconstpointer a,
 }
 
 
-bool DIskSpace::ldsm_mount_is_user_ignore (const char *path)
+bool DiskSpace::ldsm_mount_is_user_ignore (const char *path)
 {
     if (g_slist_find_custom (ignore_paths, path, (GCompareFunc) ldsm_ignore_path_compare) != NULL)
         return TRUE;
@@ -93,10 +93,10 @@ bool DIskSpace::ldsm_mount_is_user_ignore (const char *path)
 //    return this->ldsm_mount_is_user_ignore ((char *)key);
 //}
 
-void DIskSpace::usdLdsmGetConfig()
+void DiskSpace::usdLdsmGetConfig()
 {
     // 先取得清理提醒的百分比时机
-    free_percent_notify =settings->get(SETTINGS_FREE_PC_NOTIFY_KEY).toDouble();
+    free_percent_notify = settings->get(SETTINGS_FREE_PC_NOTIFY_KEY).toDouble();
     if (free_percent_notify >= 1 || free_percent_notify < 0) {
         /* FIXME define min and max in gschema! */
         qWarning ("housekeeping: Invalid configuration of free_percent_notify: %f\n" \
@@ -113,10 +113,10 @@ void DIskSpace::usdLdsmGetConfig()
     }
 
     // 取得不通知的g
-    free_size_gb_no_notify = settings->get(SETTINGS_FREE_SIZE_NO_NOTIFY).toInt();
+    free_size_gb_no_notify = settings->get(SETTINGS_FREE_SIZE_NO_NOTIFY).toUInt();
     // 取得最小通知周期
     min_notify_period = settings->get(SETTINGS_MIN_NOTIFY_PERIOD).toInt();
-
+    USD_LOG(LOG_DEBUG,"free_percent_notify:%f,free_size_gb_no_notify:%d",free_percent_notify,free_size_gb_no_notify);
     if (ignore_paths != NULL) {
         g_slist_foreach (ignore_paths, (GFunc) g_free, NULL);
         g_slist_free (ignore_paths);
@@ -134,7 +134,7 @@ ldsm_free_mount_info (gpointer data)
     g_free (mount);
 }
 
-void DIskSpace::usdLdsmUpdateConfig(QString key)
+void DiskSpace::usdLdsmUpdateConfig(QString key)
 {
     usdLdsmGetConfig();
 }
@@ -165,7 +165,7 @@ is_in (const gchar *value, const gchar *set[])
     return FALSE;
 }
 
-bool DIskSpace::ldsm_mount_should_ignore (GUnixMountEntry *mount)
+bool DiskSpace::ldsm_mount_should_ignore (GUnixMountEntry *mount)
 {
     const gchar *fs, *device, *path;
 
@@ -239,7 +239,7 @@ bool DIskSpace::ldsm_mount_should_ignore (GUnixMountEntry *mount)
     return FALSE;
 }
 
-bool  DIskSpace::ldsm_mount_has_space (LdsmMountInfo *mount)
+bool  DiskSpace::ldsm_mount_has_space (LdsmMountInfo *mount)
 {
     double free_space;
     bool percent_flag = false;
@@ -250,9 +250,13 @@ bool  DIskSpace::ldsm_mount_has_space (LdsmMountInfo *mount)
     if (free_space > free_percent_notify)
         percent_flag = true;
 
-    if (((gint64) mount->buf.f_frsize * (gint64) mount->buf.f_bavail) > ((gint64) free_size_gb_no_notify * GIGABYTE))
-        size_falg = true;
+    if (((gint64) mount->buf.f_frsize * (gint64) mount->buf.f_bavail) > ((gint64) free_size_gb_no_notify * GIGABYTE) ||
+            ((double) mount->buf.f_blocks *(gint64) mount->buf.f_frsize) < ((gint64) free_size_gb_no_notify * GIGABYTE)) {
+            size_falg = true;
+    }
 
+    USD_LOG(LOG_DEBUG,"%s:(percent_flag:%d，size_falg:%d),f_frsize:%d,f_bavail:%d,f_blocks:%d,%f",g_unix_mount_get_mount_path(mount->mount),percent_flag,size_falg,
+            mount->buf.f_frsize,mount->buf.f_bavail,mount->buf.f_blocks,free_percent_notify);
     /* If it returns false, then this volume is low on space */
     return (percent_flag && size_falg);
 }
@@ -362,7 +366,7 @@ static void ldsm_analyze_path (const gchar *path)
 
 }
 
-bool DIskSpace::ldsm_notify_for_mount (LdsmMountInfo *mount,
+bool DiskSpace::ldsm_notify_for_mount (LdsmMountInfo *mount,
                                        bool       multiple_volumes,
                                        bool       other_usable_volumes)
 {
@@ -428,7 +432,7 @@ bool DIskSpace::ldsm_notify_for_mount (LdsmMountInfo *mount,
 }
 
 // 目前希望吧GList mounts替换为QList
-void DIskSpace::ldsm_maybe_warn_mounts (GList *mounts,
+void DiskSpace::ldsm_maybe_warn_mounts (GList *mounts,
                                         bool multiple_volumes,
                                         bool other_usable_volumes)
 {
@@ -502,13 +506,13 @@ void DIskSpace::ldsm_maybe_warn_mounts (GList *mounts,
         }
 
         free_space_check = (gint64) mount_info->buf.f_frsize * (gint64) mount_info->buf.f_bavail;
-        every_two_minutes_check = QString().sprintf("The volume \"%1\" has %s disk space remaining.",
-                                       g_format_size(free_space_check)).arg(g_unix_mount_guess_name(mount_info->mount));
-        printf("%s\n",every_two_minutes_check.toStdString().data());
+//        every_two_minutes_check = QString().sprintf("The volume \"%1\" has %s disk space remaining.",
+//                                       g_format_size(free_space_check)).arg(g_unix_mount_guess_name(mount_info->mount));
+//        printf("%s\n",every_two_minutes_check.toStdString().data());
     }
 }
 
-bool DIskSpace::ldsmGetIgnorePath(const gchar *path)
+bool DiskSpace::ldsmGetIgnorePath(const gchar *path)
 {
     // 取得清理忽略的目录
     QStringList ignoreList = settings->get(SETTINGS_IGNORE_PATHS).toStringList();
@@ -519,7 +523,7 @@ bool DIskSpace::ldsmGetIgnorePath(const gchar *path)
     return false;
 }
 
-bool DIskSpace::ldsm_check_all_mounts ()
+bool DiskSpace::ldsm_check_all_mounts ()
 {
     GList *mounts;
     GList *l;
@@ -545,8 +549,11 @@ bool DIskSpace::ldsm_check_all_mounts ()
 
         path = g_unix_mount_point_get_mount_path (mount_point);
         mount = g_unix_mount_at (path, time_read);
+        USD_LOG(LOG_DEBUG,"find path:%s ",path);
         g_unix_mount_point_free (mount_point);
+
         if (mount == NULL) {
+            USD_LOG(LOG_DEBUG,"skip path:%s cuz can't find mount",path);
             /* The GUnixMountPoint is not mounted */
             continue;
         }
@@ -555,39 +562,46 @@ bool DIskSpace::ldsm_check_all_mounts ()
         mount_info->mount = mount;
 
         path = g_unix_mount_get_mount_path (mount);
-
         if (g_strcmp0 (path, "/boot/efi") == 0 ||
             g_strcmp0 (path, "/boot") == 0 ){
+            USD_LOG(LOG_DEBUG,"skip path:%s ",path);
             ldsm_free_mount_info (mount_info);
+
             continue;
         }
 
         if (ldsmGetIgnorePath(path)){
+            USD_LOG(LOG_DEBUG,"skip path:%s cuz ldsmGetIgnorePath",path);
             ldsm_free_mount_info (mount_info);
             continue;
         }
 
         if (g_unix_mount_is_readonly (mount)) {
+            USD_LOG(LOG_DEBUG,"skip path:%s cuz g_unix_mount_is_readonly",path);
             ldsm_free_mount_info (mount_info);
             continue;
         }
 
         if (ldsm_mount_should_ignore (mount)) {
             ldsm_free_mount_info (mount_info);
+            USD_LOG(LOG_DEBUG,"skip path:%s cuz ldsm_mount_should_ignore",path);
             continue;
         }
 
         if (statvfs (path, &mount_info->buf) != 0) {
+            USD_LOG(LOG_DEBUG,"skip path:%s cuz statvfs",path);
             ldsm_free_mount_info (mount_info);
             continue;
         }
 
         if (ldsm_mount_is_virtual (mount_info)) {
+            USD_LOG(LOG_DEBUG,"skip path:%s cuz ldsm_mount_is_virtual",path);
             ldsm_free_mount_info (mount_info);
             continue;
         }
 
         check_mounts = g_list_prepend (check_mounts, mount_info);
+
     }
     g_list_free (mounts);
 
@@ -605,8 +619,9 @@ bool DIskSpace::ldsm_check_all_mounts ()
     }
 
     number_of_full_mounts = g_list_length (full_mounts);
-    if (number_of_mounts > number_of_full_mounts)
+    if (number_of_mounts > number_of_full_mounts){
         other_usable_volumes = TRUE;
+    }
 
     ldsm_maybe_warn_mounts (full_mounts, multiple_volumes,
                             other_usable_volumes);
@@ -617,7 +632,7 @@ bool DIskSpace::ldsm_check_all_mounts ()
     return TRUE;
 }
 
-void DIskSpace::ldsm_mounts_changed (GObject  *monitor,gpointer  data,DIskSpace *disk)
+void DiskSpace::ldsm_mounts_changed (GObject  *monitor,gpointer  data,DiskSpace *disk)
 {
     GList *mounts;
     /* remove the saved data for mounts that got removed */
@@ -630,16 +645,14 @@ void DIskSpace::ldsm_mounts_changed (GObject  *monitor,gpointer  data,DIskSpace
     disk->ldsm_check_all_mounts();
 }
 
-void DIskSpace::UsdLdsmSetup(bool check_now)
+void DiskSpace::UsdLdsmSetup(bool check_now)
 {
     if (!m_notified_hash.empty() || ldsm_timeout_cb || ldsm_monitor) {
         qWarning ("Low disk space monitor already initialized.");
         //return;
     }
     usdLdsmGetConfig();
-    connect(settings, &QGSettings::changed,
-            this,    &DIskSpace::usdLdsmUpdateConfig);
-
+    connect(settings, SIGNAL(changed(QString)), this, SLOT(usdLdsmUpdateConfig(QString)));
 #if GLIB_CHECK_VERSION (2, 44, 0)
     ldsm_monitor = g_unix_mount_monitor_get ();
 #else
@@ -653,7 +666,7 @@ void DIskSpace::UsdLdsmSetup(bool check_now)
     //ldsm_timeout_cb->start(CHECK_EVERY_X_SECONDS);
 }
 
-void DIskSpace::cleanNotifyHash() {
+void DiskSpace::cleanNotifyHash() {
     for(auto it=m_notified_hash.begin();it!=m_notified_hash.end();it++) {
         auto p = it.value();
         if (nullptr != p) {
@@ -663,7 +676,7 @@ void DIskSpace::cleanNotifyHash() {
     m_notified_hash.clear();
 }
 
-void DIskSpace::UsdLdsmClean()
+void DiskSpace::UsdLdsmClean()
 {
     cleanNotifyHash();
 
