@@ -1,7 +1,7 @@
 /* -*- Mode: C++; indent-tabs-mode: nil; tab-width: 4 -*-
  * -*- coding: utf-8 -*-
  *
- * Copyright (C) 2020 KylinSoft Co., Ltd.
+ * Copyright (C) 2023 KylinSoft Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,7 +19,6 @@
 #include "usd-ldsm-dialog.h"
 #include "ui_usd-ldsm-dialog.h"
 
-#include <QDesktopWidget>
 #include <QRect>
 #include <QImage>
 #include <QPixmap>
@@ -28,7 +27,7 @@
 #include <QFont>
 #include <QList>
 #include <QDebug>
-
+#include <QScreen>
 #include <QGSettings/qgsettings.h>
 #include <syslog.h>
 #include <glib.h>
@@ -58,44 +57,68 @@ LdsmDialog::LdsmDialog(bool other_usable_partitions,bool other_partitions,bool d
     this->mount_path=mount_path;
     this->analyze_button=nullptr;
 
-    m_fontSetting = new QGSettings(ORG_UKUI_STYLE, QByteArray(), this);
-    connect(m_fontSetting, &QGSettings::changed,[=](QString key) {
-        USD_LOG(LOG_DEBUG,"font:%s",key.toLatin1().data());
-        if (key == SYSTEM_FONT_SIZE || key == SYSTEM_FONT) {
-            updateText();
-        }
-    });
+    m_fontSetting = new QGSettings(UKUI_STYLE_SCHEMA, QByteArray(), this);
+    connect(m_fontSetting, SIGNAL(changed(QString)), this, SLOT(updateText(QString)));
 
     windowLayoutInit(display_baobab);
     allConnectEvent(display_baobab);
-
-
 }
 
 LdsmDialog::~LdsmDialog()
 {
-    delete ui;
-    delete picture_label;
-    delete primary_label;
-    delete second_label;
-    delete ignore_check_button;
-    delete ignore_button;
+    if (ui) {
+        delete ui;
+        ui = nullptr;
+    }
 
-    if(this->has_trash)
+    if (picture_label) {
+        delete picture_label;
+        picture_label = nullptr;
+    }
+
+    if (primary_label) {
+        delete primary_label;
+        primary_label = nullptr;
+    }
+
+    if (ignore_check_button) {
+        delete ignore_check_button;
+        ignore_check_button = nullptr;
+    }
+
+    if (ignore_button) {
+        delete ignore_button;
+        ignore_button = nullptr;
+    }
+
+    if(this->has_trash) {
         delete trash_empty;
-    if(analyze_button)
+        trash_empty = nullptr;
+    }
+
+    if(analyze_button) {
         delete analyze_button;
+        analyze_button = nullptr;
+    }
 }
 
 void LdsmDialog::windowLayoutInit(bool display_baobab)
 {
     QFont font;
-    QDesktopWidget* desktop=QApplication::desktop();
-    QRect desk_rect = desktop->screenGeometry(desktop->screenNumber(QCursor::pos()));
+
     Qt::WindowFlags flags=Qt::Dialog;
+    QRect desk_rect;
+    if (QGuiApplication::screenAt(QCursor::pos()) == nullptr) {
+        desk_rect = QGuiApplication::primaryScreen()->geometry();
+    } else {
+        desk_rect = QGuiApplication::screenAt(QCursor::pos())->geometry();
+    }
+
     flags |=Qt::WindowMinMaxButtonsHint;
     flags |=Qt::WindowCloseButtonHint;
+
     setWindowFlags(flags);
+    setAttribute(Qt::WA_AlwaysShowToolTips, true);
     setFixedSize(660,210);
     setWindowIcon(QIcon::fromTheme("dialog-warning"));
     int dialog_width=width();
@@ -106,87 +129,69 @@ void LdsmDialog::windowLayoutInit(bool display_baobab)
     setWindowTitle(tr("Low Disk Space"));
     this->move((rect_width-dialog_width)/2+desk_rect.left(),(rect_height-dialog_height)/2+desk_rect.top());
 
-    picture_label=new QLabel(this);
-    primary_label=new QLabel(this);
-    second_label=new QLabel(this);
-    ignore_check_button=new QCheckBox(this);
-
+    picture_label = new QLabel(this);
+    primary_label = new QLabel(this);
+    scroll_area = new QScrollArea(this);
+    ignore_check_button = new QCheckBox(this);
     ignore_button=new QPushButton(this);
+
+    picture_label->setProperty("Name", "picture_label");
+    primary_label->setProperty("Name", "primary_label");
+    scroll_area->setProperty("Name", "scroll_area");
+    scroll_area->setFrameShape(QFrame::NoFrame);
+    ignore_check_button->setProperty("Name", "ignore_check_button");
+    ignore_button->setProperty("Name", "ignore_button");
+
     //warning picture
     picture_label->setGeometry(20,40,32,32);
     picture_label->setAlignment(Qt::AlignCenter);
     picture_label->setStyleSheet(QString("border-image:url(../ldsm_dialog/warning.png);"));
     //warning information text
-    primary_label->setGeometry(66,20,560,30);
-    second_label->setGeometry(66,50,560,30*2);
-    second_label->setWordWrap(true);
-    second_label->setAlignment(Qt::AlignLeft);
+    scroll_area->setGeometry(50, 20, 560, 40*2);
+    scroll_area->setWidget(primary_label);
+    scroll_area->setWidgetResizable(true);
+    primary_label->setGeometry(50, 20, 560, 40*2);
 
+    primary_label->setWordWrap(true);
+    primary_label->setAlignment(Qt::AlignLeft);
 
     primary_label->setText(getPrimaryText());
-    second_label->setText(getSecondText());
+//    primary_label->adjustSize();
+
     //gsettings set box
-    ignore_check_button->setGeometry(70,135,400,30);
+    ignore_check_button->setGeometry(70,120,400,30);
     ignore_check_button->setText(getCheckButtonText());
 
-    ignore_button->setGeometry(dialog_width-110,dialog_height-40,100,30);
-    ignore_button->setText(tr("Ignore"));
+    ignore_button->setGeometry(dialog_width-110,dialog_height-55,96,36);
+    ignore_button->setText(tr("Confirm"));
 
     if(this->has_trash){
         trash_empty = new QPushButton(this);
-        trash_empty->setGeometry(dialog_width-240,dialog_height-40,120,30);
+        trash_empty->setProperty("Name", "trash_empty_button");
+        trash_empty->setGeometry(dialog_width-240,dialog_height-55,96,36);
         trash_empty->setText(tr("Empty Trash"));
     }
     if(display_baobab){
         analyze_button = new QPushButton(this);
         analyze_button->setText(tr("Examine"));
         if(this->has_trash)
-            analyze_button->setGeometry(dialog_width-320,dialog_height-40,100,30);
+            analyze_button->setGeometry(dialog_width-320,dialog_height-55,96,36);
         else
-            analyze_button->setGeometry(dialog_width-215,dialog_height-40,100,30);
+            analyze_button->setGeometry(dialog_width-215,dialog_height-55,96,36);
     }
-
-    updateText();
+    updateText("");
 }
 
 QString LdsmDialog::getPrimaryText()
 {
-    QString primary_text;
-    char* free_space=g_format_size(space_remaining);
-    if(other_partitions)
-        primary_text=QString().sprintf((tr("The volume \"%1\" has only %s disk space remaining.")).toLocal8Bit().constData(),
-                                       free_space).arg(partition_name);
-    else
-        primary_text=QString().sprintf((tr("The computer has only %s disk space remaining.")).toLocal8Bit().constData(),
-                                       free_space);
-    return primary_text;
-}
-
-QString LdsmDialog::getSecondText()
-{
-    if(other_usable_partitions){
-        if(has_trash)
-            return QString(tr("You can free up disk space by emptying the Trash, removing " \
-                           "unused programs or files, or moving files to another disk or partition."));
-        else
-            return QString(tr("You can free up disk space by removing unused programs or files, " \
-                           "or by moving files to another disk or partition."));
-    }else{
-        if(has_trash)
-            return QString(tr("You can free up disk space by emptying the Trash, removing unused " \
-                           "programs or files, or moving files to an external disk."));
-        else
-            return QString(tr("You can free up disk space by removing unused programs or files, " \
-                           "or by moving files to an external disk."));
-    }
+    char* free_space = g_format_size(space_remaining);
+    return QString(tr("The remaining space of drive \"%1\" is less than %2, "\
+                            "clear the garbage or move the data to another disk in time.")).arg(partition_name).arg(free_space);
 }
 
 QString LdsmDialog::getCheckButtonText()
 {
-    if(other_partitions)
-        return QString(tr("Don't show any warnings again for this file system"));
-    else
-        return QString(tr("Don't show any warnings again"));
+    return QString(tr("Messages that no longer remind this disk"));
 }
 
 void LdsmDialog::allConnectEvent(bool display_baobab)
@@ -238,33 +243,55 @@ void LdsmDialog::checkButtonTrashEmpty()
     done(LDSM_DIALOG_RESPONSE_EMPTY_TRASH);
 }
 
-void LdsmDialog::updateText()
+void LdsmDialog::updateText(QString key)
 {
-    QFont font;
-    uint font_size ;
+    USD_LOG(LOG_DEBUG,"get key:%s",key.toLatin1().data());
 
-    if (true == m_fontSetting->keys().contains(SYSTEM_FONT_SIZE)) {
-        font_size = m_fontSetting->get(SYSTEM_FONT_SIZE).toUInt();
+    if(has_trash) {
+        resetFont(trash_empty, tr("Empty Trash"));
+    }
+
+    resetFont(ignore_button, tr("Confirm"));
+}
+
+void LdsmDialog::resetFont(QWidget *pWid, QString str)
+{
+    QPushButton *pBtn = nullptr;
+    QLabel *pLbl = nullptr;
+    int fontWidth = 0;
+    int btnWidth = 0;
+
+    if (pWid->property("Name").toString().contains("button")) {
+        pBtn = static_cast<QPushButton*>(pWid);
+    } else if (pWid->property("Name").toString().contains("label")) {
+        pLbl = static_cast<QLabel*>(pWid);
     } else {
-        font_size = 13;
+        return;
     }
 
-    if (true == m_fontSetting->keys().contains(SYSTEM_FONT)) {
-        font.setFamily(m_fontSetting->get(SYSTEM_FONT).toString());
+    QFontMetrics qFm(pWid->font());
+    fontWidth = qFm.horizontalAdvance(str);
+    if (pBtn != nullptr) {
+        btnWidth = pBtn->width() - 7;
+        if (fontWidth >= btnWidth) {
+            QString elideNote = qFm.elidedText(pBtn->text(), Qt::ElideRight, btnWidth);
+            pBtn->setText(elideNote);
+            pBtn->setToolTip(str);
+        } else {
+            pBtn->setText(str);
+            pBtn->setToolTip("");
+        }
+    } else {
+        btnWidth = pLbl->width() - 7;
+        if (fontWidth >= btnWidth) {
+            QString elideNote = qFm.elidedText(pLbl->text(), Qt::ElideRight, btnWidth);
+            pLbl->setText(elideNote);
+            pLbl->setToolTip(str);
+        } else {
+            pLbl->setText(str);
+            pLbl->setToolTip("");
+        }
     }
-
-    font.setBold(true);
-    font.setPixelSize(font_size+2);
-    primary_label->setFont(font);
-
-    font.setBold(false);
-    font.setPixelSize(font_size);
-
-    second_label->setFont(font);
-    ignore_button->setFont(font);
-    ignore_button->setFont(font);
-    trash_empty->setFont(font);
-    ignore_check_button->setFont(font);
 }
 
 void LdsmDialog::checkButtonAnalyze()
