@@ -1,7 +1,7 @@
 /* -*- Mode: C++; indent-tabs-mode: nil; tab-width: 4 -*-
  * -*- coding: utf-8 -*-
  *
- * Copyright (C) 2020 KylinSoft Co., Ltd.
+ * Copyright (C) 2023 KylinSoft Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,6 +19,9 @@
 #ifndef KEYBINDINGSPLUGIN_H
 #define KEYBINDINGSPLUGIN_H
 
+
+//(xlib 宏定义与qt5.15版本枚举冲突)keybindings-wayland-manager.h
+#include "keybindings-wayland-manager.h"
 #include "keybindings-manager.h"
 #include "plugin-interface.h"
 
@@ -35,7 +38,9 @@ private:
     KeybindingsPlugin(KeybindingsPlugin&)=delete;
 
 private:
-    static KeybindingsManager *mKeyManager;
+    KeybindingsManager *m_xKeyManager = nullptr;
+    KeybindingsWaylandManager* m_waylandKeyManager = nullptr;
+
     static PluginInterface    *mInstance;
 
 };
