@@ -1,7 +1,7 @@
 /* -*- Mode: C++; indent-tabs-mode: nil; tab-width: 4 -*-
  * -*- coding: utf-8 -*-
  *
- * Copyright (C) 2020 KylinSoft Co., Ltd.
+ * Copyright (C) 2023 KylinSoft Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,7 +29,6 @@
 #include <QDBusReply>
 
 #include <QTimer>
-#include <QtX11Extras/QX11Info>
 
 #include <QGSettings/qgsettings.h>
 #include <QApplication>
@@ -38,7 +37,7 @@
 #include "keyboard-xkb.h"
 #include "keyboard-widget.h"
 #include "usd_base_class.h"
-
+#include "plugin-manager-interface.h"
 #ifdef HAVE_X11_EXTENSIONS_XF86MISC_H
 #include <X11/extensions/xf86misc.h>
 #endif
@@ -49,7 +48,7 @@
 #endif
 
 class KeyboardXkb;
-class KeyboardManager : public QObject
+class KeyboardManager : public ManagerInterface
 {
     Q_OBJECT
 private:
@@ -57,13 +56,13 @@ private:
     KeyboardManager(KeyboardManager&)=delete;
     KeyboardManager&operator=(const KeyboardManager&)=delete;
     KeyboardManager(QObject *parent = nullptr);
-
+    bool isCloudDesktopTop();
 
 public:
     ~KeyboardManager();
     static KeyboardManager *KeyboardManagerNew();
-    bool KeyboardManagerStart();
-    void KeyboardManagerStop ();
+    virtual bool Start();
+    virtual void Stop();
     void usd_keyboard_manager_apply_settings(KeyboardManager *manager);
     void numlock_install_xkb_callback ();
 
