@@ -1,7 +1,7 @@
 /* -*- Mode: C++; indent-tabs-mode: nil; tab-width: 4 -*-
  * -*- coding: utf-8 -*-
  *
- * Copyright (C) 2020 KylinSoft Co., Ltd.
+ * Copyright (C) 2023 KylinSoft Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,21 +20,25 @@
 #include "clib-syslog.h"
 
 PluginInterface * KeyboardPlugin::mInstance=nullptr;
-KeyboardManager * KeyboardPlugin::UsdKeyboardManager=nullptr;
 
 KeyboardPlugin::KeyboardPlugin()
 {
     USD_LOG(LOG_DEBUG,"KeyboardPlugin initializing!");
-    if(nullptr == UsdKeyboardManager)
-        UsdKeyboardManager = KeyboardManager::KeyboardManagerNew();
+
+    if (UsdBaseClass::isXcb()) {
+        KeyboardManager = KeyboardManager::KeyboardManagerNew();
+    } else {
+        //wayland
+        KeyboardManager = KeyboardWaylandManager::KeyboardWaylandManagerNew();
+    }
 }
 
 KeyboardPlugin::~KeyboardPlugin()
 {
     USD_LOG(LOG_DEBUG,"Keyboard plugin free");
-    if (UsdKeyboardManager){
-        delete UsdKeyboardManager;
-        UsdKeyboardManager =nullptr;
+    if (KeyboardManager){
+        delete KeyboardManager;
+        KeyboardManager = nullptr;
     }
 }
 
@@ -42,7 +46,10 @@ void KeyboardPlugin::activate()
 {
     bool res;
     USD_LOG (LOG_DEBUG, "Activating %s plugin compilation time:[%s] [%s]",MODULE_NAME,__DATE__,__TIME__);
-    res = UsdKeyboardManager->KeyboardManagerStart();
+    if (KeyboardManager) {
+        res = KeyboardManager->Start();
+    }
+
     if(!res){
         USD_LOG(LOG_ERR,"Unable to start Keyboard Manager!")
     }
@@ -60,7 +67,9 @@ PluginInterface * KeyboardPlugin::getInstance()
 void KeyboardPlugin::deactivate()
 {
     USD_LOG(LOG_DEBUG,"Deactivating Keyboard Plugin");
-    UsdKeyboardManager->KeyboardManagerStop();
+    if (KeyboardManager) {
+        KeyboardManager->Stop();
+    }
 }
 
 PluginInterface *createSettingsPlugin()
