@@ -37,6 +37,10 @@
 #define CIRCLES_PROGRESS_INTERVAL (0.5 / N_CIRCLES)
 #define CIRCLE_PROGRESS(p) (MIN (1., ((gdouble) (p) * 2.)))
 
+#define POINTER_SCHEMA          "org.ukui.SettingsDaemon.plugins.input-device-manager"
+#define POINTER_KEY             "locate-pointer"
+
+
 typedef struct UsdLocatePointerData UsdLocatePointerData;
 
 struct UsdLocatePointerData
@@ -613,7 +617,7 @@ mouse_callback (GSettings          *settings,
                 const gchar        *key,
                 gpointer           *manager)
 {
-    if(g_strcmp0 (key, "locate-pointer") == 0){
+    if(g_strcmp0 (key, POINTER_KEY) == 0){
         GdkDisplay *display = gdk_display_get_default ();
         usd_locate_pointer (display);
     }
@@ -624,7 +628,7 @@ int main (int argc, char *argv[])
     gtk_init (&argc, &argv);
 
     //set_locate_pointer ();
-    GSettings *settings = g_settings_new ("org.ukui.SettingsDaemon.plugins.mouse");
+    GSettings *settings = g_settings_new (POINTER_SCHEMA);
     g_signal_connect (settings, "changed",
                       G_CALLBACK (mouse_callback), NULL);
 
