@@ -1,7 +1,7 @@
 /* -*- Mode: C++; indent-tabs-mode: nil; tab-width: 4 -*-
  * -*- coding: utf-8 -*-
  *
- * Copyright (C) 2020 KylinSoft Co., Ltd.
+ * Copyright (C) 2023 KylinSoft Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,9 +20,9 @@
 #define UKUIXSETTINGSMANAGER_H
 
 #include <glib.h>
-#include <X11/Xatom.h>
-#include <X11/Xcursor/Xcursor.h>
-#include <X11/extensions/Xfixes.h>
+#include <QObject>
+#include <QTimer>
+
 
 #include <glib/gi18n.h>
 #include <gdk/gdk.h>
@@ -30,10 +30,10 @@
 //#include "ixsettings-manager.h"
 #include "xsettings-manager.h"
 #include "fontconfig-monitor.h"
-
-
-class ukuiXSettingsManager
+#include "x11-head.h"
+class ukuiXSettingsManager:public QObject
 {
+    Q_OBJECT
 public:
     ukuiXSettingsManager();
     ~ukuiXSettingsManager();
@@ -41,13 +41,19 @@ public:
     int stop();
 
     void sendSessionDbus();
-
+    void setKwinMouseSize(int size);
+public Q_SLOTS:
+    void doStartTimeout();
+public:
     //gboolean setup_xsettings_managers (ukuiXSettingsManager *manager);
+
     XsettingsManager **pManagers;
     GHashTable  *gsettings;
     GSettings   *gsettings_font;
     //GSettings   *plugin_settings;
     fontconfig_monitor_handle_t *fontconfig_handle;
+    private:
+    QTimer *m_pStartTimer;
 };
 
 #endif // UKUIXSETTINGSMANAGER_H
