@@ -1,7 +1,7 @@
 /* -*- Mode: C++; indent-tabs-mode: nil; tab-width: 4 -*-
  * -*- coding: utf-8 -*-
  *
- * Copyright (C) 2020 KylinSoft Co., Ltd.
+ * Copyright (C) 2023 KylinSoft Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,12 +19,18 @@
 #include <QDebug>
 #include "ukui-xsettings-plugin.h"
 #include "clib-syslog.h"
+#include "usd_base_class.h"
 
 PluginInterface *XSettingsPlugin::mInstance =nullptr;
 ukuiXSettingsManager *XSettingsPlugin::m_pukuiXsettingManager = nullptr;
 
 XSettingsPlugin::XSettingsPlugin()
 {
+
+    if (!UsdBaseClass::isXcb()) {
+        USD_LOG(LOG_DEBUG,"is wayland exit...");
+        return;
+    }
     if(nullptr == m_pukuiXsettingManager)
         m_pukuiXsettingManager = new ukuiXSettingsManager();
 }
@@ -40,18 +46,22 @@ XSettingsPlugin::~XSettingsPlugin()
 void XSettingsPlugin::activate()
 {
     bool res;
-
-    res = m_pukuiXsettingManager->start();
-    if (!res) {
-        qWarning ("Unable to start XSettingsPlugin manager");
+    if (m_pukuiXsettingManager) {
+        res = m_pukuiXsettingManager->start();
+        if (!res) {
+            USD_LOG (LOG_DEBUG, "Unable to start XSettingsPlugin manager");
+        }
+        USD_LOG (LOG_DEBUG, "Activating %s plugin compilation time:[%s] [%s]",MODULE_NAME,__DATE__,__TIME__);
+    } else {
+        USD_LOG (LOG_DEBUG, "Unactivating %s plugin compilation time:[%s] [%s]",MODULE_NAME,__DATE__,__TIME__);
     }
-    USD_LOG (LOG_DEBUG, "Activating %s plugin compilation time:[%s] [%s]",MODULE_NAME,__DATE__,__TIME__);
-
 }
 
 void XSettingsPlugin::deactivate()
 {
-    m_pukuiXsettingManager->stop();
+    if (m_pukuiXsettingManager) {
+        m_pukuiXsettingManager->stop();
+    }
 }
 PluginInterface *XSettingsPlugin::getInstance()
 {
@@ -59,6 +69,7 @@ PluginInterface *XSettingsPlugin::getInstance()
         mInstance = new XSettingsPlugin();
     return mInstance;
 }
+
 PluginInterface* createSettingsPlugin() {
     return XSettingsPlugin::getInstance();
 }
